@@ -2,21 +2,21 @@ import os
 import ast
 import random
 import json
+import humanize
+import typing
 
 import string
 import logging
-import discord
+import disnake
 
-from discord.ext import commands
-from discord.utils import get
-from discord_components import *
-
-import youtube_dl
-from datetime import datetime, timedelta
+from disnake.ext import commands
+from disnake.utils import get
+import youtube_dl # +
+from datetime import datetime, timedelta # +
 import subprocess
 
 import time
-import requests
+import requests # +
 
 class newCommandir:
 
@@ -25,6 +25,7 @@ class newCommandir:
 	"""
 
 	aokuCommands = []
+	onMemberJoin = []
 
 	def __init__(self, name: str = None, code: list = None):
 		self.name = name
@@ -33,8 +34,9 @@ class newCommandir:
 
 		newCommandir.aokuCommands.append(self)
 
+
 class aokuBot(newCommandir):
-	def __init__(self, intents: bool = None, selfbot: bool = None):
+	def __init__(self, intents: bool = False, selfbot: bool = False):
 		"""
 		create aokuBot for future use
 		:param (bool) intents: turn on or turn off intents
@@ -43,21 +45,20 @@ class aokuBot(newCommandir):
 		self.intents = intents
 		self.selfbot = selfbot
 		if self.intents == True and self.selfbot == True:
-			self.client = commands.Bot(command_prefix = "aoku!", intents = discord.Intents.all(), self_bot = True)
+			self.client = commands.Bot(command_prefix = "aoku!", intents = disnake.Intents.all(), self_bot = True)
 		elif self.intents == False and self.selfbot == False:
 			self.client = commands.Bot(command_prefix = "aoku!")
 		elif self.intents == False and self.selfbot == True:
 			self.client = commands.Bot(command_prefix = "aoku!", self_bot = True)
 		elif self.intents == True and self.selfbot == False:
-			self.client = commands.Bot(command_prefix = "aoku!", intents = discord.Intents.all())
+			self.client = commands.Bot(command_prefix = "aoku!", intents = disnake.Intents.all())
 
 	def onReady(self, text):
+		"""
+		Prints a message to the screen when the bot is ready to use
+		"""
 		@self.client.event
 		async def on_ready():
-			"""
-			Prints a message to the screen when the bot is ready to use
-			"""
-			DiscordComponents(self.client)
 			print(text)
 
 	def newCommand(self, name: str = None, code: list = None):
@@ -91,11 +92,18 @@ class aokuBot(newCommandir):
 						codestatus = {
 							"onlyForIDs": False,
 							"onlyAdmin": False,
-							"onlyForServers": False
+							"onlyForServers": False,
+							"argsCheck": False,
+							"reply": False,
+							"embed": False,
+							"iters": False
 						}
 
-						embed = discord.Embed()
+						embed = disnake.Embed()
+						butembed = disnake.Embed()
 						botinfo = await self.client.application_info()
+						global view
+						view = disnake.ui.View()
 
 						logger = logging.getLogger(__name__)
 						c_handler = logging.StreamHandler()
@@ -160,7 +168,6 @@ class aokuBot(newCommandir):
 								aokucode = aokucode.replace(f"$onlyForServers[{onlyservers}]", f"")
 							break
 
-
 						while "$jsonRequest[" in aokucode:
 							request = aokucode.split("$jsonRequest[")[1].split("]")[0].split(";")
 							try:
@@ -231,7 +238,7 @@ class aokuBot(newCommandir):
 								insert_returns(body)
 								env = {
 									"bot":self.client,
-									'discord': discord,
+									'disnake': disnake,
 									'commands': commands,
 									'ctx': ctx,
 									'__import__': __import__
@@ -240,11 +247,11 @@ class aokuBot(newCommandir):
 								result = (await eval(f"{fn_name}()", env))
 								aokucode = aokucode.replace(f"$dpyEval[{dpycode}]", "")
 							except Exception as e:
-								aokucode = aokucode.replace(f"$dpyEval[{dpycode}]", e)
+								aokucode = aokucode.replace(f"$dpyEval[{dpycode}]", str(e))
 								break
 
 						while "$authorAvatar" in aokucode:
-							aokucode = aokucode.replace("$authorAvatar",f"{message.author.avatar_url}")
+							aokucode = aokucode.replace("$authorAvatar",f"{message.author.avatar.url}")
 							break
 
 						while "$botOwnerID" in aokucode: # -----------ПРОВЕРЕНО------------------
@@ -255,8 +262,8 @@ class aokuBot(newCommandir):
 						while "$userAvatar[" in aokucode: # -----------ПРОВЕРЕНО------------------
 							avatarkaa = aokucode.split("$userAvatar[")[1].split("]")[0]
 							user = await self.client.fetch_user(avatarkaa)
-							aokucode = aokucode.replace(f"$userAvatar[{avatarkaa}]"), str(user.avatar_url)
-							break
+							aokucode = aokucode.replace(f"$userAvatar[{avatarkaa}]", f"{user.avatar.url}")
+							#break
 
 						while "$botGuilds" in aokucode: # -----------ПРОВЕРЕНО------------------
 							aokucode = aokucode.replace("$botGuilds", f"{len(self.client.guilds)}")
@@ -275,17 +282,18 @@ class aokuBot(newCommandir):
 						while "$findUserID[" in aokucode: # -----------ПРОВЕРЕНО------------------
 							try:
 								finduserid = aokucode.split("$findUserID[")[1].split("]")[0]
-								strelkarak = discord.utils.get(message.guild.members, name=finduserid)
+								strelkarak = disnake.utils.get(message.guild.members, name=finduserid)
 								aokucode = aokucode.replace(f"$findUserID[{finduserid}]", f"{strelkarak.id}")
 							except Exception as e:
 								aokucode = aokucode.replace(f"$findUserID[{finduserid}]", f"findUserID: Incorrect UserID in $findUser[{finduserid}]")
-								logger.error(f"findUserID: Incorrect UserID in $findUserШВ[{finduserid}]")
+								logger.error(f"findUserID: Incorrect UserID in $findUserID[{finduserid}]")
 								break
 
+
 						while "$guildID" in aokucode:
 							try:
 								guildname = aokucode.split("$guildID[")[1].split("]")[0]
-								ayeguild = discord.utils.get(self.client.guilds, name = guildname)
+								ayeguild = disnake.utils.get(self.client.guilds, name = guildname)
 								aokucode = aokucode.replace(f"$guildID[{guildname}]", f"{ayeguild.id}")
 							except Exception as e:
 								aokucode = aokucode.replace(f"$guildID[{guildname}]", f"```Error while running this function\n{e}```")
@@ -295,13 +303,13 @@ class aokuBot(newCommandir):
 						while "$setBotStatus[" in aokucode:
 							botstat = aokucode.split("$setBotStatus[")[1].split("]")[0].split(";")
 							if "online" in botstat[0]:
-								await self.client.change_presence(status = discord.Status.online, activity = discord.Activity(name=f'{botstat[1]}', type = discord.ActivityType.watching))
+								await self.client.change_presence(status = disnake.Status.online, activity = disnake.Activity(name=f'{botstat[1]}', type = disnake.ActivityType.watching))
 								aokucode = aokucode.replace(f"$setBotStatus[{botstat[0]};{botstat[1]}]", f"")
 							if "dnd" in botstat[0]:
-								await self.client.change_presence(status = discord.Status.dnd, activity = discord.Activity(name=f'{botstat[1]}', type = discord.ActivityType.watching))
+								await self.client.change_presence(status = disnake.Status.dnd, activity = disnake.Activity(name=f'{botstat[1]}', type = disnake.ActivityType.watching))
 								aokucode = aokucode.replace(f"$setBotStatus[{botstat[0]};{botstat[1]}]", f"")
 							if "idle" in botstat[0]:
-								await self.client.change_presence(status = discord.Status.idle, activity = discord.Activity(name=f'{botstat[1]}', type = discord.ActivityType.watching))
+								await self.client.change_presence(status = disnake.Status.idle, activity = disnake.Activity(name=f'{botstat[1]}', type = disnake.ActivityType.watching))
 								aokucode = aokucode.replace(f"$setBotStatus[{botstat[0]};{botstat[1]}]", f"")
 							else:
 								aokucode = aokucode.replace(f"$setBotStatus[{botstat[0]};{botstat[1]}]", "```setBotStatus: Invalid usage```")
@@ -445,7 +453,7 @@ class aokuBot(newCommandir):
 						while "$highestRoleName[" in aokucode:
 							try:
 								usersea = aokucode.split("$highestRoleName[")[1].split("]")[0]
-								userkvas = discord.utils.get(message.guild.members, id = int(usersea))
+								userkvas = disnake.utils.get(message.guild.members, id = int(usersea))
 								if "$authorID" in usersea:
 									aokucode = aokucode.replace(f"$highestRoleName[$authorID]", f"{message.author.roles[-1].name}")
 								else:
@@ -458,7 +466,7 @@ class aokuBot(newCommandir):
 						while "$highestRoleID[" in aokucode:
 							try:
 								usersea = aokucode.split("$highestRoleID[")[1].split("]")[0]
-								userkvas = discord.utils.get(message.guild.members, id = int(usersea))
+								userkvas = disnake.utils.get(message.guild.members, id = int(usersea))
 								if "$authorID" in usersea:
 									aokucode = aokucode.replace(f"$highestRoleID[{usersea}]", f"{message.author.roles[-1].id}")
 								else:
@@ -637,8 +645,8 @@ class aokuBot(newCommandir):
 
 						while "$giveRole[" in aokucode:
 							userandrole = aokucode.split("$giveRole[")[1].split("]")[0].split(";")
-							resmember = discord.utils.get(message.guild.members, id=int(userandrole[0]))
-							resrole = discord.utils.get(message.guild.roles, id = int(userandrole[1]))
+							resmember = disnake.utils.get(message.guild.members, id=int(userandrole[0]))
+							resrole = disnake.utils.get(message.guild.roles, id = int(userandrole[1]))
 							try:
 								await resmember.add_roles(resrole)
 								aokucode = aokucode.replace(f"$giveRole[{userandrole[0]};{userandrole[1]}]", f"")
@@ -649,8 +657,8 @@ class aokuBot(newCommandir):
 
 						while "$takeRole[" in aokucode:
 							userandrole = aokucode.split("$takeRole[")[1].split("]")[0].split(";")
-							resmember = discord.utils.get(message.guild.members, id=int(userandrole[0]))
-							resrole = discord.utils.get(message.guild.roles, id = int(userandrole[1]))
+							resmember = disnake.utils.get(message.guild.members, id=int(userandrole[0]))
+							resrole = disnake.utils.get(message.guild.roles, id = int(userandrole[1]))
 							try:
 								await resmember.remove_roles(resrole)
 								aokucode = aokucode.replace(f"$takeRole[{userandrole[0]};{userandrole[1]}]", f"")
@@ -702,7 +710,7 @@ class aokuBot(newCommandir):
 								'before_options': '-reconnect 1 -reconnect_streamed 1 -reconnect_delay_max 5',
 								'options': '-vn'
 							}
-							
+
 							try:
 								voice_client = get(self.client.voice_clients, guild = message.guild)
 								with youtube_dl.YoutubeDL(ydl_opts) as ydl:
@@ -710,8 +718,8 @@ class aokuBot(newCommandir):
 									self.musicFile = file
 									# кончил от лица пики
 									path = file['formats'][0]['url']
-									voice_client.play(discord.FFmpegPCMAudio(source = path, **ffmpeg_opts))
-									voice_client.source = discord.PCMVolumeTransformer(voice_client.source, 1)
+									voice_client.play(disnake.FFmpegPCMAudio(source = path, **ffmpeg_opts))
+									voice_client.source = disnake.PCMVolumeTransformer(voice_client.source, 1)
 							except Exception as e:
 								aokucode = aokucode.replace(f"$playSong[{url}]", "You may not be connected to a voice channel")
 								logger.error(f"$playSong: {e}")
@@ -748,7 +756,7 @@ class aokuBot(newCommandir):
 
 						while "$songViews" in aokucode:
 							try:
-								aokucode = aokucode.replace("$songViews", f"{self.musicFile['view_count']:,}")
+								aokucode = aokucode.replace("$songViews", f"{humanize.intword(self.musicFile['view_count'])}")
 							except AttributeError:
 								aokucode = aokucode.replace("$songViews", f"```aokuMusicError: Song is not playing now```")
 							break
@@ -769,14 +777,14 @@ class aokuBot(newCommandir):
 
 						while "$songLikes" in aokucode:
 							try:
-								aokucode = aokucode.replace("$songLikes", f"{self.musicFile['like_count']:,}")
+								aokucode = aokucode.replace("$songLikes", f"{humanize.intword(self.musicFile['like_count'])}")
 							except AttributeError:
 								aokucode = aokucode.replace("$songLikes", f"```aokuMusicError: Song is not playing now```")
 							break
 
 						while "$songDislikes" in aokucode:
 							try:
-								aokucode = aokucode.replace("$songDislikes", f"{self.musicFile['dislike_count']:,}")
+								aokucode = aokucode.replace("$songDislikes", f"{humanize.intword(self.musicFile['dislike_count'])}")
 							except AttributeError:
 								aokucode = aokucode.replace("$songDislikes", f"```aokuMusicError: Song is not playing now```")
 							break
@@ -811,81 +819,150 @@ class aokuBot(newCommandir):
 								await channel.send(f"{howmuchrepeat[1]}")
 							aokucode = aokucode.replace(f"$repeatMessage[{int(howmuchrepeat)[0]};{howmuchrepeat[1]}]", str(""))
 
+						class aokuButton(disnake.ui.Button):
+							def __init__(
+								self,
+								name: typing.Union[str, int, float] = None,
+								ephemeral = "false",
+								buttcode = None
+							):
+								super().__init__(
+									label = name,
+									style = random.choice([
+										disnake.ButtonStyle.primary,
+										disnake.ButtonStyle.secondary,
+										disnake.ButtonStyle.success,
+										disnake.ButtonStyle.danger,
+										disnake.ButtonStyle.blurple,
+										disnake.ButtonStyle.gray,
+										disnake.ButtonStyle.green,
+										disnake.ButtonStyle.red
+									])
+								)
+								self.buttcode = buttcode
+								self.ephemeral = ephemeral
+							async def callback(self, iter: disnake.MessageInteraction):
+								view = self.view
+
+								if self.ephemeral == "false":
+									ephe = False
+								elif self.ephemeral == "true":
+									ephe = True
+								while "$interactionAuthorID" in self.buttcode:
+									self.buttcode = self.buttcode.replace("$interactionAuthorID", str(iter.author.id))
+									break
+								while "$interactionAuthor" in self.buttcode:
+									self.buttcode = self.buttcode.replace("$interactionAuthor", str(iter.author))
+									break
+								while "$interactionAvatarURL" in self.buttcode:
+									self.buttcode = self.buttcode.replace("$interactionAvatarURL", str(iter.author.display_avatar.url))
+									break
+								while "$interactionMe" in self.buttcode:
+									self.buttcode = self.buttcode.replace("$interactionMe", str(iter.me))
+									break
+
+								await iter.response.send_message(f"{self.buttcode}", ephemeral = ephe)
+
 						if "$createButton[" in aokucode: #----------ПРОВЕРЕНО-----------
-							def check(m):
-								return m.author == m.message.author and m.channel == m.channel
-
 							buttmsg = aokucode.split("$createButton[")[1].split("]")[0].split(";")
+							if codestatus['onlyForIDs'] == True:
+								break
+							else:
+								view.add_item(aokuButton(name = buttmsg[0], ephemeral = buttmsg[1], buttcode = buttmsg[2]))
+								codestatus['iters'] = True
+								aokucode = aokucode.replace(f"$createButton[{buttmsg[0]};{buttmsg[1]};{buttmsg[2]}]", f"")
 
-							if buttmsg[1] == "random":
-								randcolor = [ButtonStyle.blue, ButtonStyle.green, ButtonStyle.red]
+						if "$urlButton[" in aokucode:
+							urlbutt = aokucode.split("$urlButton[")[1].split("]")[0].split(";")
+							if codestatus['onlyForIDs'] == True:
+								return
+							else:
+								view.clear_items()
+								view.add_item(disnake.ui.Button(label = urlbutt[0], url = urlbutt[1]))
+								codestatus['iters'] = True
+								aokucode = aokucode.replace(f"$urlButton[{urlbutt[0]};{urlbutt[1]}]", f"")
 
-								endcolor = random.choice(randcolor)
-								knopki = await channel.send(
-									buttmsg[0],
-									components = [
-										Button(style = endcolor, label = buttmsg[2], id = "em1")]
+						class aokuSelect(disnake.ui.Select):
+							def __init__(
+								self,
+								name = None,
+								description = None,
+								emoji = None,
+								placeholder = None,
+							):
+								options = [
+									disnake.SelectOption(
+										label = name, description = description, emoji = emoji
+									)
+								]
+
+								super().__init__(
+									placeholder = placeholder,
+									min_values = 1,
+									max_values = 1,
+									options = options
 								)
 
-
-							res = await self.client.wait_for(
-								"button-click",
-								check=check,
-								timeout = 300
-							)
-
-							aokucode = aokucode.replace(f"$createButton[{buttmsg};{buttcolor};{buttlabel}]", str(knopki))
+								async def callback(self, inter: disnake.MessageInteraction):
+									await inter.response.send_message(f"работает! {self.values[0]}")
 
 						if "$createSelectMenu[" in aokucode: #----------ПРОВЕРЕНО-----------
 							try:
 								menus = aokucode.split("$createSelectMenu[")[1].split("]")[0].split(";")
-								select_menu = await channel.send(
-									menus[0],
-									components = [
-										Select(
-											placeholder = menus[1],
-											options = [
-												SelectOption(emoji = menus[2], label = menus[3], description = menus[4], value = "e1")
-											]
+								if codestatus['onlyForIDs'] == True:
+									break
+								else:
+									view.clear_items()
+									view.add_item(
+										aokuSelect(
+											name = menus[0],
+											description = menus[1],
+											emoji = menus[2],
+											placeholder = menus[3]
 										)
-									]
-								)
-								res = await self.client.wait_for("select_option")
-								await res.respond(content = f"Вы выбрали: {res.component.emoji}")
-								aokucode = aokucode.replace(f"$createSelectMenu[{menus[0]};{menus[1]};{menus[2]};{menus[3]};{menus[4]}]", str(select_menu))
-							except IndexError as e:
-								aokucode = aokucode.replace(f"$createSelectMenu[{menus[0]};{menus[1]};{menus[2]};{menus[3]};{menus[4]}])", "```createSelectMenu: Incorrect parameters```")
-								logger.error("$createSelectMenu: Incorrect parameters")
+									)
+
+									codestatus['iters'] = True
+									aokucode = aokucode.replace(f"$createSelectMenu[{menus[0]};{menus[1]};{menus[2]};{menus[3]}]", f"")
+							except Exception as e:
+								aokucode = aokucode.replace(f"$createSelectMenu[{menus[0]};{menus[1]};{menus[2]};{menus[3]}]", f"```createSelectMenu: Incorrect Parameters```")
+								logger.error("$createSelectMenu: Incorrect Parameters")
+
 
 						if "$setTitle[" in aokucode:
 							title = aokucode.split("$setTitle[")[1].split("]")[0]
+							codestatus['embed'] = True
 							embed.title = title
 							aokucode = aokucode.replace(f"$setTitle[{title}]", str(""))
-						
+
 						if "$setDescription[" in aokucode:
 							descr = aokucode.split("$setDescription[")[1].split("]")[0]
+							codestatus['embed'] = True
 							embed.description = descr
 							aokucode = aokucode.replace(f"$setDescription[{descr}]", str(""))
 
 						if "$setColor[" in aokucode:
 							colar = aokucode.split("$setColor[")[1].split("]")[0]
+							codestatus['embed'] = True
 							if colar == "random":
-								embed.color = discord.Color.random()
+								embed.color = disnake.Color.random()
 								aokucode = aokucode.replace(f"$setColor[random]", str(""))
 							else:
 								embed.color = eval(f"0x{str(colar)}")
 								aokucode = aokucode.replace(f"$setColor[{colar}]", str(""))
 
 
+
 						if "$setFooter[" in aokucode:
 							try:
 								fo = aokucode.split("$setFooter[")[1].split("]")[0].split(";")
+								codestatus['embed'] = True
 								if "$authorAvatar" in fo[1]:
 									aokucode = aokucode.replace(f"$setFooter[{fo[0]};$authorAvatar]", str(""))
-									embed.set_footer(text = fo[0], icon_url = message.author.avatar_url)
+									embed.set_footer(text = fo[0], icon_url = message.author.avatar.url)
 								elif "$botAvatar" in fo[1]:
 									aokucode = aokucode.replace(f"$setFooter[{fo[0]};$botAvatar]", str(""))
-									embed.set_footer(text=fo[0], icon_url = self.client.user.avatar_url)
+									embed.set_footer(text=fo[0], icon_url = self.client.user.avatar.url)
 								else:
 									aokucode = aokucode.replace(f"$setFooter[{fo[0]};{fo[1]}]", str(""))
 									embed.set_footer(text = fo[0], icon_url = fo[1])
@@ -893,17 +970,19 @@ class aokuBot(newCommandir):
 								foer = aokucode.split("$setFooter[")[1].split("]")[0]
 								aokucode = aokucode.replace(f"$setFooter[{foer}]", str(""))
 								embed.set_footer(text = foer)
+
 								logger.error(f"$setFooter: {e}")
 
 
 						if "$setThumbnail[" in aokucode:
 							yser = aokucode.split("$setThumbnail[")[1].split("]")[0]
+							codestatus['embed'] = True
 							if "$authorAvatar" in yser:
 								aokucode = aokucode.replace(f"$setThumbnail[{yser}]", str(""))
-								embed.set_thumbnail(url = message.author.avatar_url)
+								embed.set_thumbnail(url = message.author.avatar.url)
 							elif "$botAvatar" in yser:
 								aokucode = aokucode.replace(f"$setThumbnail[{yser}]", str(""))
-								embed.set_thumbnail(url = self.client.user.avatar_url)
+								embed.set_thumbnail(url = self.client.user.avatar.url)
 							else:
 								aokucode = aokucode.replace(f"$setThumbnail[{yser}]", str(""))
 								embed.set_thumbnail(url = yser)
@@ -912,12 +991,13 @@ class aokuBot(newCommandir):
 						if "$setAuthor[" in aokucode:
 							try:
 								kote = aokucode.split("$setAuthor[")[1].split("]")[0].split(";")
+								codestatus['embed'] = True
 								if "$authorAvatar" in kote[1]:
 									aokucode = aokucode.replace(f"$setAuthor[{kote[0]};$authorAvatar]", str(""))
-									embed.set_author(name=kote[0], icon_url = message.author.avatar_url)
+									embed.set_author(name=kote[0], icon_url = message.author.avatar.url)
 								elif "$botAvatar" in kote[1]:
 									aokucode = aokucode.replace(f"$setAuthor[{kote[0]};$botAvatar]", str(""))
-									embed.set_author(name = kote[0], icon_url = self.client.user.avatar_url)
+									embed.set_author(name = kote[0], icon_url = self.client.user.avatar.url)
 								else:
 									aokucode = aokucode.replace(f"$setAuthor[{kote[0]};{kote[1]}]", str(""))
 									embed.set_author(name = kote[0], icon_url = kote[1])
@@ -930,6 +1010,7 @@ class aokuBot(newCommandir):
 						if "$addField[" in aokucode:
 							try:
 								aine = aokucode.split("$addField[")[1].split("]")[0].split(";")
+								codestatus['embed'] = True
 								aokucode = aokucode.replace(f"$addField[{aine[0]};{aine[1]}]", str(""))
 								embed.add_field(name = aine[0], value = aine[1])
 							except IndexError:
@@ -938,12 +1019,13 @@ class aokuBot(newCommandir):
 
 						if "$setImage[" in aokucode:
 							tea = aokucode.split("$setImage[")[1].split("]")[0]
+							codestatus['embed'] = True
 							if "$authorAvatar" in tea:
 								aokucode = aokucode.replace("$setImage[$authorAvatar]", str(""))
-								embed.set_image(url = message.author.avatar_url)
+								embed.set_image(url = message.author.avatar.url)
 							elif "$botAvatar" in tea:
 								aokucode = aokucode.replace("$setImage[$botAvatar]", str(""))
-								embed.set_image(url = self.client.user.avatar_url)
+								embed.set_image(url = self.client.user.avatar.url)
 							else:
 								aokucode = aokucode.replace(f"$setImage[{tea}]", str(""))
 								embed.set_image(url = tea)
@@ -956,7 +1038,6 @@ class aokuBot(newCommandir):
 								await server.leave()
 							except:
 								aokucode = aokucode.replace("$botLeave", "botLeave: Failed to leave the server")
-								raise aokuCodeError("In function $botLeave raised an error")
 
 						if "$botLeave" in aokucode:
 							aokucode = aokucode.replace("$botLeave", f"")
@@ -971,19 +1052,33 @@ class aokuBot(newCommandir):
 						if codestatus['onlyForServers'] == True:
 							break
 
+						if codestatus['argsCheck'] == True:
+							break
 						try:
-							await message.channel.send(aokucode, embed=embed)
-						except Exception as e:
-							try:
+							if codestatus['embed'] == True and codestatus['iters'] == True:
+								await message.channel.send(embed = embed, view = view)
+								codestatus['embed'] = False
+								codestatus['iters'] = False
+							if codestatus['embed'] == True and codestatus['iters'] == False:
+								await message.channel.send(aokucode, embed = embed)
+								codestatus['embed'] = False
+								codestatus['iters'] = False
+							if codestatus['embed'] == False and codestatus['iters'] == True:
+								await message.channel.send(aokucode, view = view)
+								codestatus['embed'] = False
+								codestatus['iters'] = False
+							else:
 								await message.channel.send(aokucode)
-							except Exception as e:
-								pass
+								codestatus['embed'] = False
+								codestatus['iters'] = False
+						except Exception as e:
+							pass
 
-	def start(self, token, selfbot: bool = None):
+	def start(self, token, selfbot: bool = False):
 		try:
 			if selfbot == False:
 				self.client.run(token)
 			elif selfbot == True:
 				self.client.run(token, bot = False)
 		except Exception as e:
-			print("Ошибка подключения к Discord!\n\n{0}".format(str(e)))
\ No newline at end of file
+			print("Ошибка подключения к Discord!\n\n{0}".format(str(e)))
